"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Item = void 0;
const internal_1 = require("../internal");
class Item extends internal_1.State {
    /**
     * @public
     * Item of Collection
     * @param collection - Collection to which the Item belongs
     * @param data - Data that the Item holds
     * @param config - Config
     */
    constructor(collection, data, config = {}) {
        super(collection.agileInstance(), data, {
            isPlaceholder: config.isPlaceholder,
            key: data[collection.config.primaryKey],
        });
        this.isSelected = false; // If Item is selected by a Selector
        this.collection = () => collection;
        // Reassign Key to assign sideEffects
        this.setKey(data[collection.config.primaryKey], {
            updateItemValuePrimaryKey: false,
        });
    }
    //=========================================================================================================
    // Set Key
    //=========================================================================================================
    /**
     * @internal
     * Updates Key/Name of State
     * @param value - New Key/Name of State
     * @param config - Config
     */
    setKey(value, config = {}) {
        super.setKey(value);
        config = internal_1.defineConfig(config, {
            sideEffects: true,
            background: false,
            force: false,
            storage: true,
            overwrite: false,
            updateItemValuePrimaryKey: true,
        });
        if (!value)
            return this;
        // Remove old rebuildGroupsThatIncludeItemKey sideEffect
        this.removeSideEffect(Item.updateGroupSideEffectKey);
        // Add rebuildGroupsThatIncludeItemKey to sideEffects to rebuild Groups that include this Item if it changes
        this.addSideEffect(Item.updateGroupSideEffectKey, (config) => this.collection().rebuildGroupsThatIncludeItemKey(value, config));
        // Update ItemKey in ItemValue (After updating the sideEffect because otherwise it calls the old sideEffect)
        if (config.updateItemValuePrimaryKey)
            this.patch({ [this.collection().config.primaryKey]: value }, {
                sideEffects: config.sideEffects,
                background: config.background,
                force: config.force,
                storage: config.storage,
                overwrite: config.overwrite,
            });
        // Initial Rebuild (not necessary if updating primaryKey in ItemValue because a sideEffect of the patch method is to rebuild the Group)
        if (!config.updateItemValuePrimaryKey)
            this.collection().rebuildGroupsThatIncludeItemKey(value, {
                background: config.background,
                force: config.force,
                sideEffects: config.sideEffects,
            });
        return this;
    }
}
exports.Item = Item;
Item.updateGroupSideEffectKey = 'rebuildGroup';
