import { Observer, RuntimeJob, ObserverKey, Event, SubscriptionContainer, IngestConfigInterface, RuntimeJobConfigInterface, RuntimeJobKey } from '../internal';
export declare class EventObserver<PayloadType = any> extends Observer {
    event: () => Event<PayloadType>;
    /**
     * @internal
     * Event Observer - Handles Event dependencies and ingests Event triggers into the Runtime
     * @param event - Event
     * @param config - Config
     */
    constructor(event: Event<PayloadType>, config?: CreateEventObserverConfigInterface);
    /**
     * @internal
     * Ingests Event into Runtime and causes Rerender on Components that got subscribed by the Event (Observer)
     * @param config - Config
     */
    trigger(config?: EventIngestConfigInterface): void;
    /**
     * @internal
     * Performs Job from Runtime
     * @param job - Job that gets performed
     */
    perform(job: RuntimeJob<this>): void;
}
/**
 * @param deps - Initial Dependencies of Event Observer
 * @param subs - Initial Subscriptions of Event Observer
 * @param key - Key/Name of Event Observer
 */
export interface CreateEventObserverConfigInterface {
    deps?: Array<Observer>;
    subs?: Array<SubscriptionContainer>;
    key?: ObserverKey;
}
/**
 * @param key - Key/Name of Job that gets created
 */
export interface EventIngestConfigInterface extends RuntimeJobConfigInterface, IngestConfigInterface {
    key?: RuntimeJobKey;
}
