"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EventObserver = void 0;
const internal_1 = require("../internal");
class EventObserver extends internal_1.Observer {
    /**
     * @internal
     * Event Observer - Handles Event dependencies and ingests Event triggers into the Runtime
     * @param event - Event
     * @param config - Config
     */
    constructor(event, config = {}) {
        super(event.agileInstance(), {
            deps: config.deps,
            key: config.key,
            subs: config.subs,
        });
        this.event = () => event;
    }
    //=========================================================================================================
    // Ingest
    //=========================================================================================================
    /**
     * @internal
     * Ingests Event into Runtime and causes Rerender on Components that got subscribed by the Event (Observer)
     * @param config - Config
     */
    trigger(config = {}) {
        config = internal_1.defineConfig(config, {
            perform: true,
            background: false,
            sideEffects: true,
            force: false,
        });
        // Create Job
        const job = new internal_1.RuntimeJob(this, {
            force: config.force,
            sideEffects: config.sideEffects,
            background: config.background,
            key: config.key || this._key,
        });
        this.agileInstance().runtime.ingest(job, {
            perform: config.perform,
        });
    }
    //=========================================================================================================
    // Perform
    //=========================================================================================================
    /**
     * @internal
     * Performs Job from Runtime
     * @param job - Job that gets performed
     */
    perform(job) {
        // Noting to perform
    }
}
exports.EventObserver = EventObserver;
