"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Observer = void 0;
const internal_1 = require("../internal");
class Observer {
    /**
     * @internal
     * Observer - Handles subscriptions and dependencies of an Agile Class and is like an instance to the Runtime
     * Note: No stand alone class!!
     * @param agileInstance - An instance of Agile
     * @param config - Config
     */
    constructor(agileInstance, config = {}) {
        var _a, _b;
        this.deps = new Set(); // Observers that depends on this Observer
        this.subs = new Set(); // SubscriptionContainers (Components) that this Observer has subscribed
        config = internal_1.defineConfig(config, {
            deps: [],
            subs: [],
        });
        this.agileInstance = () => agileInstance;
        this._key = config.key;
        this.value = config.value;
        (_a = config.deps) === null || _a === void 0 ? void 0 : _a.forEach((observer) => this.depend(observer));
        (_b = config.subs) === null || _b === void 0 ? void 0 : _b.forEach((subscriptionContainer) => this.subscribe(subscriptionContainer));
    }
    /**
     * @internal
     * Set Key/Name of Observer
     */
    set key(value) {
        this._key = value;
    }
    /**
     * @internal
     * Get Key/Name of Observer
     */
    get key() {
        return this._key;
    }
    //=========================================================================================================
    // Perform
    //=========================================================================================================
    /**
     * @internal
     * Performs Job of Runtime
     * @param job - Job that gets performed
     */
    perform(job) {
        internal_1.Agile.logger.warn("Perform function isn't Set in Observer! Be aware that Observer is no stand alone class!");
    }
    //=========================================================================================================
    // Depend
    //=========================================================================================================
    /**
     * @internal
     * Adds Dependency to Observer that will be ingested into the Runtime if this Observer changes
     * @param observer - Observer that will depend on this Observer
     */
    depend(observer) {
        if (!this.deps.has(observer))
            this.deps.add(observer);
    }
    //=========================================================================================================
    // Subscribe
    //=========================================================================================================
    /**
     * @internal
     * Adds Subscription to Observer
     * @param subscriptionContainer - SubscriptionContainer(Component) that gets subscribed by this Observer
     */
    subscribe(subscriptionContainer) {
        if (!this.subs.has(subscriptionContainer)) {
            this.subs.add(subscriptionContainer);
            // Add this to subscriptionContainer to keep track of the Observers the subscriptionContainer hold
            subscriptionContainer.subs.add(this);
        }
    }
    //=========================================================================================================
    // Unsubscribe
    //=========================================================================================================
    /**
     * @internal
     * Removes Subscription from Observer
     * @param subscriptionContainer - SubscriptionContainer(Component) that gets unsubscribed by this Observer
     */
    unsubscribe(subscriptionContainer) {
        if (this.subs.has(subscriptionContainer)) {
            this.subs.delete(subscriptionContainer);
            subscriptionContainer.subs.delete(this);
        }
    }
}
exports.Observer = Observer;
