import { Observer, State, ObserverKey, SubscriptionContainer, IngestConfigInterface, StateRuntimeJob, StateRuntimeJobConfigInterface, RuntimeJobKey } from '../internal';
export declare class StateObserver<ValueType = any> extends Observer {
    state: () => State<ValueType>;
    nextStateValue: ValueType;
    /**
     * @internal
     * State Observer - Handles State changes, dependencies (-> Interface to Runtime)
     * @param state - State
     * @param config - Config
     */
    constructor(state: State<ValueType>, config?: CreateStateObserverConfigInterface);
    /**
     * @internal
     * Ingests nextStateValue or computedValue into Runtime and applies it to the State
     * @param config - Config
     */
    ingest(config?: StateIngestConfigInterface): void;
    /**
     * @internal
     * Ingests new State Value into Runtime and applies it to the State
     * @param newStateValue - New Value of the State
     * @param config - Config
     */
    ingestValue(newStateValue: ValueType, config?: StateIngestConfigInterface): void;
    /**
     * @internal
     * Performs Job that holds this Observer
     * @param job - Job
     */
    perform(job: StateRuntimeJob): void;
    /**
     * @internal
     * SideEffects of Job
     * @param job - Job
     */
    sideEffects(job: StateRuntimeJob): void;
}
/**
 * @param deps - Initial Dependencies of State Observer
 * @param subs - Initial Subscriptions of State Observer
 * @param key - Key/Name of State Observer
 */
export interface CreateStateObserverConfigInterface {
    deps?: Array<Observer>;
    subs?: Array<SubscriptionContainer>;
    key?: ObserverKey;
}
/**
 * @param key - Key/Name of Job that gets created
 */
export interface StateIngestConfigInterface extends StateRuntimeJobConfigInterface, IngestConfigInterface {
    key?: RuntimeJobKey;
}
